@@ -20,14 +20,9 @@ else:
     except ImportError:
         from git_run import GitRun
 
-__version__ = '1.0.13'
+__version__ = '1.0.16'
 
-MANIFEST_FILES = [
-    '__manifest__.py',
-    '__odoo__.py',
-    '__openerp__.py',
-    '__terp__.py',
-]
+MANIFEST_FILES = ['__manifest__.py', '__odoo__.py', '__openerp__.py', '__terp__.py']
 
 
 def is_module(path):
@@ -40,19 +35,18 @@ def is_module(path):
     files = os.listdir(path)
     filtered = [x for x in files if x in (MANIFEST_FILES + ['__init__.py'])]
     if len(filtered) == 2 and '__init__.py' in filtered:
-        return os.path.join(
-            path, next(x for x in filtered if x != '__init__.py'))
+        return os.path.join(path, next(x for x in filtered if x != '__init__.py'))
     else:
         return False
 
 
 def get_modules(path, depth=1):
-    """ Return modules of path repo (used in test_server.py)"""
+    """Return modules of path repo (used in test_server.py)"""
     return sorted(list(get_modules_info(path, depth).keys()))
 
 
 def get_modules_info(path, depth=1):
-    """ Return a digest of each installable module's manifest in path repo"""
+    """Return a digest of each installable module's manifest in path repo"""
     # Avoid empty basename when path ends with slash
     path = os.path.expanduser(path)
     if not os.path.basename(path):
@@ -74,8 +68,7 @@ def get_modules_info(path, depth=1):
                         'auto_install': manifest.get('auto_install'),
                     }
             else:
-                deeper_modules = get_modules_info(
-                    os.path.join(path, module), depth-1)
+                deeper_modules = get_modules_info(os.path.join(path, module), depth - 1)
                 modules.update(deeper_modules)
     return modules
 
@@ -95,11 +88,13 @@ def get_addons(path, depth=1):
     if is_addons(path):
         res.append(path)
     else:
-        new_paths = [os.path.join(path, x)
-                     for x in sorted(os.listdir(path))
-                     if os.path.isdir(os.path.join(path, x))]
+        new_paths = [
+            os.path.join(path, x)
+            for x in sorted(os.listdir(path))
+            if os.path.isdir(os.path.join(path, x))
+        ]
         for new_path in new_paths:
-            res.extend(get_addons(new_path, depth-1))
+            res.extend(get_addons(new_path, depth - 1))
     return res
 
 
@@ -118,16 +113,16 @@ def get_modules_changed(path, ref='HEAD'):
             fetch_ref += ':' + fetch_ref
         git_run_obj.run(['fetch'] + fetch_ref.split('/', 1))
     items_changed = git_run_obj.get_items_changed(ref)
-    folders_changed = set([
+    folders_changed = {
         item_changed.split('/')[0]
         for item_changed in items_changed
-        if '/' in item_changed]
-    )
+        if '/' in item_changed
+    }
     modules = set(get_modules(path))
     modules_changed = list(modules & folders_changed)
     modules_changed_path = [
-        os.path.join(path, module_changed)
-        for module_changed in modules_changed]
+        os.path.join(path, module_changed) for module_changed in modules_changed
+    ]
     return modules_changed_path
 
 
@@ -137,7 +132,7 @@ def get_dependencies(modules, module_name):
     result = set()
     for dependency in modules.get(module_name, {}).get('depends', []):
         result |= get_dependencies(modules, dependency)
-    return result | set([module_name])
+    return result | {module_name}
 
 
 def get_dependents(modules, module_name):
@@ -147,28 +142,32 @@ def get_dependents(modules, module_name):
     for dependent in modules.keys():
         if module_name in modules.get(dependent, {}).get('depends', []):
             result |= get_dependents(modules, dependent)
-    return result | set([module_name])
+    return result | {module_name}
 
 
 def add_auto_install(modules, to_install):
-    """ Append automatically installed glue modules to to_install if their
-    dependencies are already present. to_install is a set. """
+    """Append automatically installed glue modules to to_install if their
+    dependencies are already present. to_install is a set."""
     found = True
     while found:
         found = False
         for module, module_data in modules.items():
-            if (module_data.get('auto_install') and
-                    module not in to_install and
-                    all(dependency in to_install
-                        for dependency in module_data.get('depends', []))):
+            if (
+                module_data.get('auto_install')
+                and module not in to_install
+                and all(
+                    dependency in to_install
+                    for dependency in module_data.get('depends', [])
+                )
+            ):
                 found = True
                 to_install.add(module)
     return to_install
 
 
 def get_applications_with_dependencies(modules):
-    """ Return all modules marked as application with their dependencies.
-    For our purposes, l10n modules cannot be an application. """
+    """Return all modules marked as application with their dependencies.
+    For our purposes, l10n modules cannot be an application."""
     result = set()
     for module, module_data in modules.items():
         if module_data.get('application') and not module.startswith('l10n_'):
@@ -177,8 +176,7 @@ def get_applications_with_dependencies(modules):
 
 
 def get_localizations_with_dependents(modules):
-    """ Return all localization modules with the modules that depend on them
-    """
+    """Return all localization modules with the modules that depend on them"""
     result = set()
     for module in modules.keys():
         if module.startswith('l10n_'):
